@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 1.5
+;; Version: 1.6
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -1056,9 +1056,10 @@ This command dispatches to the following commands:
       (jinx-mode -1)))
    (jinx-mode
     (jinx--load-module)
-    (let ((enable-local-variables :safe)
-          (enable-local-eval nil)
-          (enable-dir-local-variables nil))
+    (cl-letf* ((enable-local-variables :safe)
+               (enable-local-eval nil)
+               ;; Fix reentrancy problem (gh:minad/jinx#158)
+               ((symbol-function #'jinx-mode) #'ignore))
       (hack-local-variables 'ignore-mode))
     (jinx--get-org-language)
     (setq jinx--exclude-regexp
